@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "flycheck" "36.0"
+(define-package "flycheck" "20251119.1203"
   "On-the-fly syntax checking."
   '((emacs "27.1")
     (seq   "2.24"))
-  :url "https://github.com/flycheck/flycheck"
-  :commit "ebddfd89b1eea91b8590f542908672569942fb82"
-  :revdesc "ebddfd89b1ee"
+  :url "https://www.flycheck.org"
+  :commit "1eafe2911d50c9f58efce81ff8abea59495e1ff3"
+  :revdesc "1eafe2911d50"
   :keywords '("convenience" "languages" "tools")
   :authors '(("Sebastian Wiesner" . "swiesner@lunaryorn.com"))
   :maintainers '(("Clément Pit-Claudel" . "clement.pitclaudel@live.com")
